==> ros-geometric-shapes_0.7.0.orig.tar.gz: geometric_shapes-0.7.0/include/geometric_shapes/solid_primitive_dims.h <==
/*********************************************************************
 * Software License Agreement (BSD License)
 *
 *  Copyright (c) 2012, Willow Garage, Inc.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of the Willow Garage nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *********************************************************************/

#pragma once

#include <shape_msgs/SolidPrimitive.h>

namespace geometric_shapes
{
/** \brief The number of dimensions of a particular shape */
template <int>
struct SolidPrimitiveDimCount
{
  enum
  {
    value = 0u
  };
};

template <>
struct SolidPrimitiveDimCount<shape_msgs::SolidPrimitive::SPHERE>
{
  enum
  {
    value = 1u
  };
};

template <>
struct SolidPrimitiveDimCount<shape_msgs::SolidPrimitive::BOX>
{
  enum
  {
    value = 3u
  };
};

template <>
struct SolidPrimitiveDimCount<shape_msgs::SolidPrimitive::CONE>
{
  enum
  {
    value = 2u
  };
};

template <>
struct SolidPrimitiveDimCount<shape_msgs::SolidPrimitive::CYLINDER>
{
  enum
  {
    value = 2u
  };
};
}  // namespace geometric_shapes

==> ros-geometric-shapes_0.7.3.orig.tar.gz: geometric_shapes-0.7.3/include/geometric_shapes/solid_primitive_dims.h <==
/*********************************************************************
 * Software License Agreement (BSD License)
 *
 *  Copyright (c) 2012, Willow Garage, Inc.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of the Willow Garage nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *********************************************************************/

#pragma once

#include <shape_msgs/SolidPrimitive.h>

namespace geometric_shapes
{
/** Get the number of dimensions of a particular shape */
template <int shape>
constexpr unsigned int solidPrimitiveDimCount();

template <>
constexpr unsigned int solidPrimitiveDimCount<shape_msgs::SolidPrimitive::SPHERE>()
{
  return 1u;
}

template <>
constexpr unsigned int solidPrimitiveDimCount<shape_msgs::SolidPrimitive::BOX>()
{
  return 3u;
}

template <>
constexpr unsigned int solidPrimitiveDimCount<shape_msgs::SolidPrimitive::CYLINDER>()
{
  return 2u;
}

template <>
constexpr unsigned int solidPrimitiveDimCount<shape_msgs::SolidPrimitive::CONE>()
{
  return 2u;
}

// clang-format off
template <int shape>
struct [[deprecated("Replace SolidPrimitiveDimCount<SHAPE>::value with solidPrimitiveDimCount<SHAPE>()")]]
SolidPrimitiveDimCount
// clang-format on
{
  enum
  {
    value = solidPrimitiveDimCount<shape>()
  };
};

}  // namespace geometric_shapes
